@@ -5,7 +5,7 @@ Copyright (C) 2010-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 partially based on C++ code from:
 Copyright (C) 2006 Mauricio Piacentini <mauricio@tabuleiro.com>
 
-SPDX-License-Identifier: GPL-2.0
+SPDX-License-Identifier: GPL-2.0-only
 
 """
 
@@ -28,14 +28,16 @@ class MJTableView(QTableView):
     """a QTableView with app specific defaults"""
 
     def __init__(self, parent:Optional['QWidget']=None) ->None:
-        QTableView.__init__(self, parent)
-        self.horizontalHeader().setStretchLastSection(True)
+        super().__init__(parent)
+        if header := self.horizontalHeader():
+            header.setStretchLastSection(True)
         self.setAlternatingRowColors(True)
         pol = QSizePolicy()
         pol.setHorizontalPolicy(QSizePolicy.Policy.Expanding)
         pol.setVerticalPolicy(QSizePolicy.Policy.Expanding)
         self.setSizePolicy(pol)
-        self.verticalHeader().hide()
+        if header := self.verticalHeader():
+            header.hide()
 
     def initView(self) ->None:
         """set some app specific defaults"""
@@ -50,7 +52,7 @@ class ListComboBox(QComboBox):
     attribute 'name'."""
 
     def __init__(self, items:List[Any], parent:Optional['QWidget']=None) ->None:
-        QComboBox.__init__(self, parent)
+        super().__init__(parent)
         self.items = items
 
     @property
@@ -146,14 +148,20 @@ def rotateCenter(item:'QGraphicsItem', angle:float) ->None:
 def sceneRotation(item:'QGraphicsItem') ->int:
     """the combined rotation of item and all parents in degrees: 0,90,180 or 270"""
     transform = item.sceneTransform()
-    matrix:Tuple[int, ...] = (
-        round(transform.m11()),
-        round(transform.m12()),
-        round(transform.m21()),
-        round(transform.m22()))
-    matrix = tuple(1 if x > 0 else -1 if x < 0 else 0 for x in matrix)
-    rotations:Dict[Tuple[int, ...], int] = {(0, 0, 0, 0): 0, (1, 0, 0, 1): 0, (
-        0, 1, -1, 0): 90, (-1, 0, 0, -1): 180, (0, -1, 1, 0): 270}
+    matrix_raw:Tuple[int, ...] = (
+        round(transform.m11()),  # horizontal scaling factor
+        round(transform.m12()),  # vertical shearing factor
+        round(transform.m21()),  # horizontal shearing factor
+        round(transform.m22()))  # vertical scaling factor
+    matrix = tuple(1 if x > 0 else -1 if x < 0 else 0 for x in matrix_raw)
+    rotations:Dict[Tuple[int, ...], int] = {
+        (0, 0, 0, 0): 0,
+        (1, 0, 0, 1): 0,
+        (0, 1, -1, 0): 90,
+        (1, 1, -1, 1): 90,
+        (-1, 0, 0, -1): 180,
+        (0, -1, 1, 0): 270,
+        (1, -1, 1, 1): 270}
     if matrix not in rotations:
-        raise ValueError(f'matrix unknown:{str(matrix)}')
+        raise ValueError(f'{item=} matrix unknown:{matrix=} {matrix_raw=}')
     return rotations[matrix]
