@@ -4,7 +4,7 @@
 """
 Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-SPDX-License-Identifier: GPL-2.0
+SPDX-License-Identifier: GPL-2.0-only
 
 """
 
@@ -15,10 +15,10 @@ import os
 import logging
 from typing import Tuple, List, Optional, Type, Any
 
-from qtpy import QT5, PYSIDE2
 from qt import QObject, QCommandLineParser, QCommandLineOption, Qt, QGuiApplication
 from kde import KApplication
 from mi18n import i18n, MLocale
+from point import PointRange
 
 from common import Options, SingleshotOptions, Internal, Debug
 # do not import modules using twisted before our reactor is running
@@ -56,7 +56,7 @@ class CommandLineOption(QCommandLineOption):
     def __init__(self, name : str, description : str, valueName : Optional[str] =None,
         defaultValue : Optional[str]=None, optName : Optional[str]=None,
         argType : Optional[Type]=None, singleshot:bool=False) ->None:
-        QCommandLineOption.__init__(self, [name], description, valueName or '', defaultValue or '')
+        super().__init__([name], description, valueName or '', defaultValue or '')
         if argType is None:
             if valueName is None:
                 argType = bool
@@ -109,7 +109,7 @@ def parseOptions() ->None:
     parser.process(Internal.app)
     for option in options:
         if parser.isSet(option):
-            value = parser.value(option)
+            value = parser.value(option) if option.valueName() else ''
             if option.optName == 'debug':
                 msg = Debug.setOptions(value)
                 if msg:
@@ -131,6 +131,8 @@ def parseOptions() ->None:
 
     Options.demo |= not Options.gui
     Internal.autoPlay = Options.demo
+    if SingleshotOptions.game:
+        PointRange.from_string(SingleshotOptions.game)  # checks for valid syntax
 
     from query import initDb
     if not initDb():
@@ -147,7 +149,7 @@ class EvHandler(QObject):
         """will be called for all events"""
         from log import EventData
         EventData(receiver, event)
-        return QObject.eventFilter(self, receiver, event)
+        return super().eventFilter(receiver, event)
 
 from util import gitHead
 
@@ -187,10 +189,5 @@ if Options.csv:
         sys.exit(2)
 
 from mainwindow import MainWindow
-if QT5:
-    QGuiApplication.setAttribute(Qt.ApplicationAttribute.AA_UseHighDpiPixmaps, True)  # type:ignore[attr-defined]
 MainWindow()
-if PYSIDE2:
-    Internal.app.exec_()
-else:
-    Internal.app.exec()
+Internal.app.exec()
